@@ -12,10 +12,12 @@
 
 #define ALL_MASK 0xffffffff
 
-#include "inotify_utils.h"
+#include "inotify.h"
+#include "event_queue.h"
 
 int main (int argc, char **argv)
 {
+	queue_t q;
 	int fd;
 
 	fd = open_dev();
@@ -24,8 +26,13 @@ int main (int argc, char **argv)
 		return 0;
 	}
 
+	q = queue_create (128);
+
 	watch_dir (fd, argv[1], ALL_MASK);
-	read_and_print_events (fd);
+
+	read_and_print_events (q, fd);
+
+	queue_destroy (q);
 
 	close_dev (fd);
 	return 0;
